# Spliced

<img src="https://github.com/buildsi/spliced/raw/main/docs/assets/img/spliced-small.png">

[![Test Spliced Action](https://github.com/buildsi/spliced/actions/workflows/test-action.yaml/badge.svg)](https://github.com/buildsi/spliced/actions/workflows/test-action.yaml)
[![Build Ubuntu Bases](https://github.com/buildsi/spliced/actions/workflows/container-bases.yaml/badge.svg)](https://github.com/buildsi/spliced/actions/workflows/container-bases.yaml)
[![Update Docs](https://github.com/buildsi/spliced/actions/workflows/docs.yml/badge.svg)](https://github.com/buildsi/spliced/actions/workflows/docs.yml)

⭐️ [View Documentation](https://buildsi.github.io/spliced/) ⭐️ 
 
## License

Spack is distributed under the terms of both the MIT license and the
Apache License (Version 2.0). Users may choose either license, at their
option.

All new contributions must be made under both the MIT and Apache-2.0
licenses.

See [LICENSE-MIT](https://github.com/spack/spack/blob/develop/LICENSE-MIT),
[LICENSE-APACHE](https://github.com/spack/spack/blob/develop/LICENSE-APACHE),
[COPYRIGHT](https://github.com/spack/spack/blob/develop/COPYRIGHT), and
[NOTICE](https://github.com/spack/spack/blob/develop/NOTICE) for details.

SPDX-License-Identifier: (Apache-2.0 OR MIT)

LLNL-CODE-811652
